@@ -35,9 +35,11 @@
 #include "glib-utils.h"
 #include "fr-archive.h"
 #include "fr-command.h"
+#include "fr-command-ace.h"
 #include "fr-command-ar.h"
 #include "fr-command-arj.h"
 #include "fr-command-cfile.h"
+#include "fr-command-cpio.h"
 #include "fr-command-iso.h"
 #include "fr-command-lha.h"
 #include "fr-command-rar.h"
@@ -305,9 +307,15 @@ create_command_from_mime_type (FRArchive  *archive,
 		   is_mime_type (mime_type, "application/x-ar")) {
 		archive->command = fr_command_ar_new (archive->process, 
 						      filename);
+	} else if (is_mime_type (mime_type, "application/x-ace")) {
+		archive->command = fr_command_ace_new (archive->process, 
+						       filename);
 	} else if (is_mime_type (mime_type, "application/x-7zip")) {
 		archive->command = fr_command_7z_new (archive->process,
 						      filename);
+	} else if (is_mime_type (mime_type, "application/x-cpio")) {
+		archive->command = fr_command_cpio_new (archive->process,
+						        filename);						      
 	} else 
 		return FALSE;
 
@@ -512,12 +520,17 @@ create_command_from_filename (FRArchive  *archive,
 		if (file_extension_is (filename, ".lzo")) {
 			archive->command = fr_command_cfile_new (archive->process, filename, FR_COMPRESS_PROGRAM_LZOP);
 			archive->is_compressed_file = TRUE;
-			return (archive->command != NULL);
+			return (archive->command != NULL);			
 		} 
+		
+		if (file_extension_is (filename, ".cpio")) {
+			archive->command = fr_command_cpio_new (archive->process,
+							        filename);
+			return (archive->command != NULL);
+		}		
 	} 
 
 	if (loading) {
-		
 		if (file_extension_is (filename, ".bin")
 		    || file_extension_is (filename, ".sit")) {
 			archive->command = fr_command_unstuff_new (archive->process,
@@ -542,6 +555,12 @@ create_command_from_filename (FRArchive  *archive,
 							      filename);
 			return (archive->command != NULL);
 		} 
+
+		if (file_extension_is (filename, ".ace")) {
+			archive->command = fr_command_ace_new (archive->process, 
+							       filename);
+			return (archive->command != NULL);
+		} 		
 	}
 
 	return FALSE;
@@ -1234,6 +1253,7 @@ fr_archive_add_with_wildcard (FRArchive     *archive,
 					     NO_BACKUP_FILES,
 					     NO_DOT_FILES,
 					     IGNORE_CASE,
+					     archive->command->propAddCanStoreFolders,
 					     add_with_wildcard__step2, 
 					     aww_data);
 }
@@ -1316,6 +1336,7 @@ fr_archive_add_directory (FRArchive     *archive,
 
 	return get_items_file_list_async (ad_data->dir_list,
 					  base_dir, 
+					  archive->command->propAddCanStoreFolders,
 					  add_directory__step2, 
 					  ad_data);
 }
@@ -1354,6 +1375,7 @@ fr_archive_add_items (FRArchive     *archive,
 
 	return get_items_file_list_async (ad_data->dir_list, 
 					  base_dir, 
+					  archive->command->propAddCanStoreFolders,
 					  add_directory__step2, 
 					  ad_data);
 }
@@ -1864,11 +1886,13 @@ fr_archive_utils__get_file_name_ext (const char *filename)
 {
 	static char * ext[] = {
 		".7z",
+		".ace",
 		".ar",
 		".arj",
 		".bin",
 		".bz", 
-		".bz2", 
+		".bz2",
+		".cpio", 
 		".deb",
 		".ear",
 		".gz", 
