@@ -33,6 +33,7 @@
 
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-command.h"
 #include "fr-command-cfile.h"
 
@@ -136,7 +137,6 @@ list__process_line (char     *line,
 	
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 	
 	if (*fdata->name == 0)
 		file_data_free (fdata);
@@ -146,7 +146,8 @@ list__process_line (char     *line,
 
 
 static void
-fr_command_cfile_list (FRCommand *comm)
+fr_command_cfile_list (FRCommand  *comm,
+		       const char *password)
 {
 	FRCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
 
@@ -187,7 +188,6 @@ fr_command_cfile_list (FRCommand *comm)
 		
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
-		fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 		
 		if (*fdata->name == 0)
 			file_data_free (fdata);
@@ -405,10 +405,8 @@ fr_command_cfile_extract (FRCommand  *comm,
 	uncompr_file = remove_extension_from_path (temp_file);
 
 	compr_file = get_uncompressed_name_from_archive (comm, comm->filename);
-	if (compr_file == NULL) {
-		g_print ("[0]\n");
+	if (compr_file == NULL) 
 		compr_file = remove_extension_from_path (file_name_from_path (comm->e_filename));
-	}
 	dest_file = g_strconcat (dest_dir,
 				 "/",
 				 compr_file,
@@ -551,5 +549,16 @@ fr_command_cfile_new (FRProcess         *process,
 	fr_command_construct (comm, process, filename);
 	FR_COMMAND_CFILE (comm)->compress_prog = prog;
 
+	if (prog == FR_COMPRESS_PROGRAM_GZIP)
+		comm->file_type = FR_FILE_TYPE_GZIP;
+	else if (prog == FR_COMPRESS_PROGRAM_BZIP)
+		comm->file_type = FR_FILE_TYPE_BZIP;
+	else if (prog == FR_COMPRESS_PROGRAM_BZIP2)
+		comm->file_type = FR_FILE_TYPE_BZIP2;
+	else if (prog == FR_COMPRESS_PROGRAM_COMPRESS)
+		comm->file_type = FR_FILE_TYPE_COMPRESS;
+	else if (prog == FR_COMPRESS_PROGRAM_LZOP)
+		comm->file_type = FR_FILE_TYPE_LZOP;
+
 	return comm;
 }
