@@ -39,6 +39,7 @@
 #include "window.h"
 #include "typedefs.h"
 #include "preferences.h"
+#include "file-data.h"
 #include "main.h"
 
 static void     prepare_app         (void);
@@ -65,12 +66,14 @@ static gint   extract_here;
 static gchar *default_url = NULL;
 
 FRFileTypeDescription file_type_desc[] = {
+	{ FR_FILE_TYPE_ACE,          ".ace",     "application/x-ace", N_("Ace (.ace)") },
 	{ FR_FILE_TYPE_AR,           ".ar",      "application/x-ar", N_("Ar (.ar)") },
-	{ FR_FILE_TYPE_DEB,          ".deb",     "application/x-deb", NULL },
 	{ FR_FILE_TYPE_ARJ,          ".arj",     "application/x-arj", N_("Arj (.arj)") },
 	{ FR_FILE_TYPE_BZIP,         ".bz",      "application/x-bzip", NULL },
 	{ FR_FILE_TYPE_BZIP2,        ".bz2",     "application/x-bzip", NULL },
 	{ FR_FILE_TYPE_COMPRESS,     ".Z",       "application/x-compress", NULL },
+	{ FR_FILE_TYPE_CPIO,         ".cpio",    "application/x-cpio", NULL },	
+	{ FR_FILE_TYPE_DEB,          ".deb",     "application/x-deb", NULL },
 	{ FR_FILE_TYPE_ISO,          ".iso",     "application/x-cd-image", NULL },
 	{ FR_FILE_TYPE_EAR,          ".ear",     "application/x-ear", N_("Ear (.ear)") },
 	{ FR_FILE_TYPE_GZIP,         ".gz",      "application/x-gzip", NULL},
@@ -105,11 +108,13 @@ FRCommandDescription command_desc[] = {
 	{ "rar",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_RAR },
 	{ "gzip",       TRUE,  TRUE,  FALSE, FR_FILE_TYPE_GZIP },
 	{ "bzip2",      TRUE,  TRUE,  FALSE, FR_FILE_TYPE_BZIP2 },
+	{ "unace",      TRUE,  FALSE, TRUE,  FR_FILE_TYPE_ACE },
 	{ "ar",         TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_AR },
 	{ "ar",         TRUE,  FALSE, TRUE,  FR_FILE_TYPE_DEB },
 	{ "arj",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_ARJ },
 	{ "bzip2",      TRUE,  FALSE, FALSE, FR_FILE_TYPE_BZIP },
 	{ "compress",   TRUE,  TRUE,  FALSE, FR_FILE_TYPE_COMPRESS },
+	{ "cpio",       TRUE,  FALSE, FALSE, FR_FILE_TYPE_CPIO },	
 	{ "isoinfo",    TRUE,  FALSE, TRUE,  FR_FILE_TYPE_ISO },
 	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_EAR },
 	{ "zip",        TRUE,  TRUE,  TRUE,  FR_FILE_TYPE_JAR },
@@ -310,6 +315,7 @@ static void
 release_data ()
 {
 	g_hash_table_destroy (programs_cache);
+	file_data_release_data ();
 
 	eel_global_client_free ();
 
@@ -494,7 +500,7 @@ prepare_app (void)
 
 	default_dir = get_path_from_url (default_url);
 
-	if ((extract_here == 0) && (extract_to != NULL)) {
+	if (extract_to != NULL) {
 		if (g_path_is_absolute (extract_to))
 			extract_to_path = get_path_from_url (extract_to);
 		else {
@@ -556,24 +562,19 @@ prepare_app (void)
 			window_set_default_dir (window, default_dir, TRUE);
 
 		while ((archive = remaining_args[i++]) != NULL) {
-			if (extract_here == 1) {
-				g_free (extract_to_path);
-				extract_to_path = g_strconcat (archive, "_FILES", NULL);
-			}
-				
-			window_archive__open_extract (window, 
-						      archive, 
-						      extract_to_path);
-
-			if (extract_here == 1) {
-				g_free (extract_to_path);
-				extract_to_path = NULL;
-			}
+			if (extract_here == 1) 
+				window_archive__open_extract_here (window, 
+								   archive, 
+								   extract_to_path);
+			else
+				window_archive__open_extract (window, 
+							      archive, 
+							      extract_to_path);
 		}
 		window_archive__quit (window);
 		window_batch_mode_start (window);
 
-	} else { /* Open each archives in a window */
+	} else { /* Open each archive in a window */
 		const char *archive;
 		
 		int i = 0;
